const fs = require('fs');
const os = require('os');

const home = os.homedir();
const route = `${home}\\.my-own-words`;

function dirExists() {
  return fs.existsSync(route);
}

function createDir() {
  return fs.mkdirSync(route);
}

function listExists(list) {
  return fs.existsSync(`${route}\\${list}.json`);
}

function createList(list) {
  return fs.writeFileSync(`${route}\\${list}.json`, '{}');
}

function getLists() {
  return fs.readdirSync(route);
}

function removeList(list) {
  return fs.unlinkSync(`${route}\\${list}.json`);
}

function getWords(list) {
  return fs.readFileSync(`${route}\\${list}.json`).toString();
}

function parseWords(json) {
  return JSON.parse(json);
}

function getAndParseWords(list) {
  return parseWords(getWords(list));
}

function sortWords(words) {
  const unsortedWords = Object.entries(words).sort();
  const sortedWords = {};

  unsortedWords.map(word => (sortedWords[word[0]] = word[1].sort()));

  return sortedWords;
}

function saveWords(list, words) {
  return fs.writeFileSync(`${route}\\${list}.json`, JSON.stringify(words));
}

function sortAndSaveWords(list, words) {
  return saveWords(list, sortWords(words));
}

module.exports = {
  dirExists,
  createDir,
  listExists,
  createList,
  getLists,
  removeList,
  getAndParseWords,
  sortWords,
  saveWords,
  sortAndSaveWords,
};
