const os = require('os');
const rimraf = require('rimraf');
const { assert } = require('chai');

const { dirExists, listExists } = require('../src/fs-helpers');
const { newList } = require('../src/new');
const { addWord } = require('../src/add');
const { list } = require('../src/list');

const home = os.homedir();
const route = `${home}\\.my-own-words`;

describe('Before #list', () => {
  before(() => {
    rimraf.sync(route);
  });

  it('should delete the test directory', () => {
    assert.isFalse(dirExists());
  });

  it('should create a clear test directory with an empty list', () => {
    const listName = 'italian';

    newList(listName);

    assert.isTrue(dirExists());
    assert.isTrue(listExists(listName));
  });
});

describe('#list', () => {
  it("should return an object with the available lists if don't receive a specific list", () => {
    const listName = 'italian';

    assert.isArray(list());
    assert.include(list(), `${listName}.json`);
  });

  it('should return an object if a list is specified and it contains words', () => {
    const listName = 'italian';
    const word = 'Ciao';

    addWord(listName, word, 'Hi');

    assert.isObject(list(listName));
    assert.hasAnyKeys(list(listName), word);
  });

  it("should return an error message if the list specified doesn't exists", () => {
    const listName = 'spanish';

    assert.strictEqual(list(listName), `${listName} list doesn't exists!`);
  });
});
