const os = require('os');
const rimraf = require('rimraf');
const { assert } = require('chai');

const { dirExists, listExists, getAndParseWords } = require('../src/fs-helpers');
const { newList } = require('../src/new');

const home = os.homedir();
const route = `${home}\\.my-own-words`;

describe('Before #newList', () => {
  before(() => {
    rimraf.sync(route);
  });

  it('should delete the test directory', () => {
    assert.isFalse(dirExists());
  });
});

describe('#newList', () => {
  it('should make a directory if that not exists', () => {
    const listName = 'italian';

    newList(listName);

    assert.isTrue(dirExists());
  });

  it('should create a list if that not exists', () => {
    const listName = 'italian';

    assert.isTrue(listExists(listName));
  });

  it('should return a message if the list already exists', () => {
    const listName = 'italian';

    assert.strictEqual(newList(listName), `${listName} list already exists!`);
  });

  it('list should contain an empty object at first', () => {
    const listName = 'italian';

    assert.isObject(getAndParseWords(listName));
  });
});
